#  Common.pm
#    - functions common to all of pgpenvelope
#
#  Copyright (C) 2000 Frank J. Tobin <ftobin@uiuc.edu>
#
#  This file is part of pgpenvelope
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, visit the following URL:
#  http://www.gnu.org/copyleft/gpl.html
#
#  $Id: Common.pm,v 1.19 2000/07/24 03:32:50 ftobin Exp $
#

package PGPEnvelope::Common;

use 5.005;

use strict;
use English;
use IO::Pipe;
use File::Spec;
use vars qw/ $VERSION /;

use constant DEBUG => 0;

$VERSION = '2.9.0';

sub version
{
    return $VERSION;
}


sub work_dir
{
    
    my $homedir = ( $ENV{PGPENVELOPE_HOME}
		    || File::Spec->catdir( $ENV{HOME}, '.pgpenvelope' )
		  );
    
    die 'cannot determine a home directory to use' unless $homedir;
    return $homedir;
}


sub prefs_filename
{
    return File::Spec->catdir( work_dir(), 'prefs' );
}



sub die_gracefully
{
    my ( $self, @message ) = @_;
    print @message;
    exit 1;
}



sub check_and_create_dir
{
    my ( $self, $work_dir ) = @_;
    
    return 1 if -d $work_dir;
    
    print "Creating $work_dir ...\n";
    return 1 if mkdir $work_dir, 0777;
    
    print "error: can't create $work_dir: $ERRNO\n";
    return 0;
}



sub explain_no_pgp5
{
    print <<EOF;

This version of pgpenvelope no longer supports PGP 5.0;
use an older version if you need to support it.
This version solely supports GnuPG, which, in my and
many other's opinion a much better, GPL'd,
OpenPGP-compliant application.

GnuPG is available at http://www.gnupg.org/

Older versions of pgpevenlope are probably available at
http://pgpenvelope.sourceforge.net/
EOF
}



sub display_warranty
{
    my $version = PGPEnvelope::Common->version();
    
    print <<EOF;

pgpenvelope $version, a Pine-with-GnuPG interface
Copyright (C) 2000 Frank J. Tobin <ftobin\@uiuc.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, visit the following URL:
    http://www.gnu.org/copyleft/gpl.html

EOF
}





1;
